# Contributing

We ❤️  any and all support that you might have to offer. That being said, there are a few guidelines that you must read up on before getting started.

## Reporting Bugs 🐞

_Never_ feel hesitant to file a bug. We want to keep this framework battle-tested and bullet-proof, and it's up to you to help us. Think about it: the worst thing that can happen is you file an invalid bug, we figure out the issue, and suddenly your code is working again. Just make sure to [do a quick search][search-issues] for your problem before opening up a new issue.

Simply [create a new issue][new-issue] and we'll do our best to respond quickly. Some examples of when you should report a new issue:
- Crashes
- Deadlocks
- Unexpected behavior
- Compiler issues
- Things just aren't working right
- Need a friend

When filing a new issue, make sure you include the following:
- Operating System (macOS, Linux)
- Xcode Version (if used)
- Platform (iOS, tvOS, watchOS, macOS, Linux)
- Your version or git SHA of Conduit
- A full stack-trace of a crash or deadlock, if applicable
- Steps on how to reproduce the issue, to the best of your ability
- Dependency manager (Carthage, CocoaPods, Swift Package Manager, manual installation)
- Any additional info that might help

## Pull Requests 🏆

No pull request is too small; we will review and may potentially accept anything from whitespace changes to feature requests, so never be afraid to [submit a new pull request][new-pull-request]. Some examples might include:
- Bug fixes
- Feature gaps
- Feature requests
- Typos
- Documentation changes
- Xcode/Platform/Language Compatibility
- etc.

Make sure to complete every item on the checklist within [PULL_REQUEST_TEMPLATE.md][pull-request-template]. Code style, tests, documentation updates, and system design will all be evaluated on each request.

## Code of Conduct

We are very strict about good contributor behavior. We honor the Contributor's Covenant Code of Conduct to maintain a welcoming environment for all developers, regardless of experience levels, identity, or expression.

Please refer to [CODE_OF_CONDUCT.md][code-of-conduct] for more details.

## Developer's Certificate of Origin 1.1

By making a contribution to this project, I certify that:

- (a) The contribution was created in whole or in part by me and I
      have the right to submit it under the open source license
      indicated in the file; or

- (b) The contribution is based upon previous work that, to the best
      of my knowledge, is covered under an appropriate open source
      license and I have the right under that license to submit that
      work with modifications, whether created in whole or in part
      by me, under the same open source license (unless I am
      permitted to submit under a different license), as indicated
      in the file; or

- (c) The contribution was provided directly to me by some other
      person who certified (a), (b) or (c) and I have not modified
      it.

- (d) I understand and agree that this project and the contribution
      are public and that a record of the contribution (including all
      personal information I submit with it, including my sign-off) is
      maintained indefinitely and may be redistributed consistent with
      this project or the open source license(s) involved.

---

[search-issues]: https://github.com/mindbody/Conduit/issues?utf8=%E2%9C%93&q=is%3Aissue%20👉🏻👉🏻👉🏻%20search%20here%20👈🏻👈🏻👈🏻
[new-issue]: https://github.com/mindbody/Conduit/issues/new
[new-pull-request]: https://github.com/mindbody/Conduit/compare
[pull-request-template]: .github/PULL_REQUEST_TEMPLATE
[code-of-conduct]: CODE_OF_CONDUCT.md